@@ -65,11 +65,46 @@ class NGramTest(CorpusTest, unittest.TestCase):
         self.complexUniGram = NGram(1, self.validationCorpus)
         self.assertEqual(35663, self.complexUniGram.vocabularySize(), 0.0)
 
+    def test_Prune(self):
+        self.simpleBiGram.prune(0.0)
+        self.assertEqual(4, self.simpleBiGram.getCount(["<s>", "ali"]), 0.0)
+        self.assertEqual(1, self.simpleBiGram.getCount(["<s>", "ayşe"]), 0.0)
+        self.assertEqual(3, self.simpleBiGram.getCount(["ali", "topu"]), 0.0)
+        self.assertEqual(1, self.simpleBiGram.getCount(["ali", "top"]), 0.0)
+        self.assertEqual(2, self.simpleBiGram.getCount(["topu", "at"]), 0.0)
+        self.assertEqual(1, self.simpleBiGram.getCount(["topu", "mehmete"]), 0.0)
+        self.simpleBiGram.prune(0.6)
+        self.assertEqual(4, self.simpleBiGram.getCount(["<s>", "ali"]), 0.0)
+        self.assertEqual(0, self.simpleBiGram.getCount(["<s>", "ayşe"]), 0.0)
+        self.assertEqual(3, self.simpleBiGram.getCount(["ali", "topu"]), 0.0)
+        self.assertEqual(0, self.simpleBiGram.getCount(["ali", "top"]), 0.0)
+        self.assertEqual(2, self.simpleBiGram.getCount(["topu", "at"]), 0.0)
+        self.assertEqual(0, self.simpleBiGram.getCount(["topu", "mehmete"]), 0.0)
+        self.simpleBiGram.prune(0.7)
+        self.assertEqual(4, self.simpleBiGram.getCount(["<s>", "ali"]), 0.0)
+        self.assertEqual(3, self.simpleBiGram.getCount(["ali", "topu"]), 0.0)
+        self.assertEqual(0, self.simpleBiGram.getCount(["topu", "at"]), 0.0)
+        self.simpleBiGram.prune(0.8)
+        self.assertEqual(4, self.simpleBiGram.getCount(["<s>", "ali"]), 0.0)
+        self.assertEqual(0, self.simpleBiGram.getCount(["ali", "topu"]), 0.0)
+        self.simpleBiGram.prune(0.9)
+        self.assertEqual(0, self.simpleBiGram.getCount(["<s>", "ali"]), 0.0)
+        
     def test_SaveAsText(self):
         self.simpleUniGram.saveAsText("simple1.txt")
         self.simpleBiGram.saveAsText("simple2.txt")
         self.simpleTriGram.saveAsText("simple3.txt")
 
+    def test_LoadMultiPart(self):
+        self.simpleUniGram = NGram(1)
+        self.simpleUniGram.initWithMultipleFile("simple1part1.txt", "simple1part2.txt")
+        self.simpleBiGram = NGram(2)
+        self.simpleBiGram.initWithMultipleFile("simple2part1.txt", "simple2part2.txt", "simple2part3.txt")
+        self.simpleTriGram = NGram(3)
+        self.simpleTriGram.initWithMultipleFile("simple3part1.txt", "simple3part2.txt", "simple3part3.txt", "simple3part4.txt")
+        self.test_GetCountSimple()
+        self.test_VocabularySizeSimple()
+
 
 if __name__ == '__main__':
     unittest.main()
